Module unity_image

Module unity_image 

Structs

UnityImage
A glTF image entry, providing the URI needed for Unity to load the texture asset.

Functions

gltforge_image_count
Return the number of images.
gltforge_image_name
Return a pointer to the UTF-8 name bytes for image image_idx. out_len receives the byte length. Returns null if image_idx is out of range.
gltforge_image_uri
Return a pointer to the UTF-8 URI bytes for image image_idx. out_len receives the byte length. Returns null if image_idx is out of range or the image is buffer-view-embedded.