Module unity_image
gltforge_
unity
0.0.4
Module unity_
image
Module Items
Structs
Functions
In crate gltforge_
unity
gltforge_unity
Module
unity_
image
Structs

Unity
Image
A glTF image entry, providing the URI needed for Unity to load the texture asset.
Functions

gltforge_
image_
count
⚠
Return the number of images.
gltforge_
image_
name
⚠
Return a pointer to the UTF-8 name bytes for image
image_idx
.
out_len
receives the byte length. Returns null if
image_idx
is out of range.
gltforge_
image_
uri
⚠
Return a pointer to the UTF-8 URI bytes for image
image_idx
.
out_len
receives the byte length. Returns null if
image_idx
is out of range or the image is buffer-view-embedded.